AppStorage class abstract

Constructors

AppStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

storage → GetStorage
no setter

Static Methods

clearStorage() → Future<void>
getValue<T>(String key) → T?
hasData(String key) → bool
removeValue(String key) → Future<void>
saveValue(String key, dynamic value) → Future<void>
updateNewValue(String key, dynamic value) → Future<void>
updateValue(String key, dynamic value) → Future<void>